;; Generated package description from load-dir.el  -*- no-byte-compile: t -*-
(define-package "load-dir" "0.0.5.0.20201129.193105" "Load all Emacs Lisp files in a given directory" '((cl-lib "0.5")) :url "https://elpa.gnu.org/packages/load-dir.html" :keywords '("lisp" "files" "convenience") :maintainer '("Teodor Zlatanov" . "tzz@lifelogs.com"))
